@@ -21,7 +21,7 @@ from annofabcli.common.cli import (
     ArgumentParser,
     build_annofabapi_resource_and_login,
 )
-from annofabcli.common.facade import TaskQuery, match_task_with_task_query
+from annofabcli.common.facade import TaskQuery, match_task_with_query
 
 logger = logging.getLogger(__name__)
 
@@ -145,7 +145,7 @@ class RejectTasksMain(AbstracCommandCinfirmInterface):
             )
             return False
 
-        if match_task_with_task_query(Task.from_dict(task), task_query):
+        if match_task_with_query(Task.from_dict(task), task_query):
             logger.debug(f"task_id = {task_id} : TaskQueryの条件にマッチしないため、スキップします。")
             return False
 
